@@ -1,5 +1,5 @@
 use crate::core::checkpoint::CheckpointFunction;
-use crate::core::element::Record;
+use crate::core::element::{FnSchema, Record};
 use crate::core::function::{Context, FlatMapFunction, NamedFunction};
 
 pub struct RoundRobinFlagMapFunction {
@@ -36,6 +36,10 @@ impl FlatMapFunction for RoundRobinFlagMapFunction {
     fn close(&mut self) -> crate::core::Result<()> {
         Ok(())
     }
+
+    fn schema(&self, input_schema: FnSchema) -> FnSchema {
+        input_schema
+    }
 }
 
 impl NamedFunction for RoundRobinFlagMapFunction {
